@@ -13,10 +13,6 @@ DATABASES = {
 
 DEBUG = True
 
-CHAVE_API = '55a4598f-800f-403f-ad56-aedbb35b90c6'
-CHAVE_APLICACAO = '7a7134e1-dfc3-4922-b145-eb8b605171aa'
-
-
 INSTALLED_APPS = (
     'repositories',
     'repositories.catalogo',
@@ -28,4 +24,3 @@ INSTALLED_APPS = (
     'repositories.pedido',
     'repositories.plataforma',
 )
-# PAGADOR_CONF_PATH = "/home/marcioduarte/projects/lojaintegrada/pagador_config.conf"
\ No newline at end of file
